@@ -118,7 +118,7 @@ def minuit():
 @pytest.fixture
 def fmin_good():
     fm = Namespace(
-        fval=1.23456e-10,
+        fval=11.456,
         edm=1.23456e-10,
         up=0.5,
         is_valid=True,
@@ -131,9 +131,10 @@ def fmin_good():
         is_above_max_edm=False,
         has_reached_call_limit=False,
         has_parameters_at_limit=False,
+        errordef=1,
         state=[],
     )
-    return FMin(fm, 10, 3, 1e-4)
+    return FMin(fm, "Migrad", 10, 3, 10, 1e-4)
 
 
 @pytest.fixture
@@ -152,6 +153,7 @@ def fmin_bad():
         is_above_max_edm=True,
         has_reached_call_limit=True,
         has_parameters_at_limit=True,
+        errordef=1,
         state=[
             Namespace(
                 has_limits=True,
@@ -165,14 +167,17 @@ def fmin_bad():
             )
         ],
     )
-    return FMin(fm, 100000, 200000, 1e-5)
+    return FMin(fm, "SciPy[L-BFGS-B]", 100000, 200000, 1, 1e-5)
 
 
 def test_html_fmin_good(fmin_good):
     # fmt: off
     assert fmin_good._repr_html_() == """<table>
     <tr>
-        <td colspan="2" style="text-align:left" title="Minimum value of function"> FCN = 1.235e-10 </td>
+        <th colspan="5" style="text-align:center" title="Minimizer"> Migrad </th>
+    </tr>
+    <tr>
+        <td colspan="2" style="text-align:left" title="Minimum value of function"> FCN = 11.46 (chi2/ndof = 1.1) </td>
         <td colspan="3" style="text-align:center" title="No. of function evaluations in last call and total number"> Nfcn = 10 </td>
     </tr>
     <tr>
@@ -180,8 +185,7 @@ def test_html_fmin_good(fmin_good):
         <td colspan="3" style="text-align:center" title="No. of gradient evaluations in last call and total number"> Ngrad = 3 </td>
     </tr>
     <tr>
-        <td style="text-align:center;{good}"> Valid Minimum </td>
-        <td style="text-align:center;{good}"> Valid Parameters </td>
+        <td colspan="2" style="text-align:center;{good}"> Valid Minimum </td>
         <td colspan="3" style="text-align:center;{good}"> No Parameters at limit </td>
     </tr>
     <tr>
@@ -202,6 +206,9 @@ def test_html_fmin_good(fmin_good):
 def test_html_fmin_bad(fmin_bad):
     # fmt: off
     assert fmin_bad._repr_html_() == """<table>
+    <tr>
+        <th colspan="5" style="text-align:center" title="Minimizer"> SciPy[L-BFGS-B] </th>
+    </tr>
     <tr>
         <td colspan="2" style="text-align:left" title="Minimum value of function"> FCN = nan </td>
         <td colspan="3" style="text-align:center" title="No. of function evaluations in last call and total number"> Nfcn = 100000 </td>
@@ -211,8 +218,7 @@ def test_html_fmin_bad(fmin_bad):
         <td colspan="3" style="text-align:center" title="No. of gradient evaluations in last call and total number"> Ngrad = 200000 </td>
     </tr>
     <tr>
-        <td style="text-align:center;{bad}"> INVALID Minimum </td>
-        <td style="text-align:center;{bad}"> INVALID Parameters </td>
+        <td colspan="2" style="text-align:center;{bad}"> INVALID Minimum </td>
         <td colspan="3" style="text-align:center;{warn}"> SOME Parameters at limit </td>
     </tr>
     <tr>
@@ -524,9 +530,6 @@ def test_text_params_with_long_names():
             None,
             False,
             False,
-            False,
-            False,
-            False,
             None,
             None,
         )
@@ -544,9 +547,6 @@ def test_text_params_difficult_values():
             None,
             True,
             False,
-            False,
-            False,
-            False,
             None,
             None,
         )
